@@ -105,6 +105,11 @@
 #' - **`geog_levels`:** A [`tibble`][tibble::tbl_df-class] containing names
 #'   and descriptions for the geographic levels available
 #'   for the time series table.
+#' - **`geographic_instances`:** A [`tibble`][tibble::tbl_df-class] containing
+#'   names and descriptions for all valid geographic extents for the
+#'   time series table. Includes all states or state equivalents that are
+#'   valid for *any* year in the time series table. (Some instances may be valid
+#'   for some but not all years.)
 #'
 #' ## Shapefiles:
 #'
@@ -288,9 +293,12 @@ get_metadata_nhgis <- function(type = NULL,
 #' Retrieve sample IDs and descriptions for IPUMS microdata collections.
 #'
 #' Currently supported microdata collections are:
-#'   - IPUMS USA (`"usa"`)
-#'   - IPUMS CPS (`"cps"`)
-#'   - IPUMS International (`"ipumsi"`)
+#'
+#' * IPUMS USA (`"usa"`)
+#' * IPUMS CPS (`"cps"`)
+#' * IPUMS International (`"ipumsi"`)
+#' * IPUMS Time Use (`"atus"`, `"ahtus"`, `"mtus"`)
+#' * IPUMS Health Surveys (`"nhis"`, `"meps"`)
 #'
 #' Learn more about the IPUMS API in `vignette("ipums-api")`.
 #'
@@ -313,7 +321,7 @@ get_metadata_nhgis <- function(type = NULL,
 #'   descriptions for the indicated collection.
 #'
 #' @seealso
-#' [`define_extract_*()`][define_extract-micro] to create an IPUMS microdata
+#' [define_extract_micro()] to create an IPUMS microdata
 #'   extract definition.
 #'
 #' @export
@@ -325,6 +333,8 @@ get_metadata_nhgis <- function(type = NULL,
 #' get_sample_info("usa")
 #' get_sample_info("cps")
 #' get_sample_info("ipumsi")
+#' get_sample_info("atus")
+#' get_sample_info("meps")
 #' }
 get_sample_info <- function(collection = NULL,
                             delay = 0,
@@ -367,7 +377,7 @@ get_summary_metadata <- function(collection,
                                  api_key = Sys.getenv("IPUMS_API_KEY")) {
   url <- api_request_url(
     collection = collection,
-    path = metadata_request_path(collection, type),
+    path = metadata_request_path(type),
     queries = list(pageNumber = 1, pageSize = api_page_size_limit("metadata"))
   )
 
@@ -418,7 +428,7 @@ get_detailed_metadata <- function(collection,
                                   api_key = Sys.getenv("IPUMS_API_KEY")) {
   url <- api_request_url(
     collection = collection,
-    path = metadata_request_path(collection = collection, ...)
+    path = metadata_request_path(...)
   )
 
   response <- ipums_api_request(
